@@ -1,5 +1,5 @@
 import requests
-from pysmashgg.exceptions import TooManyRequestsError, BadRequestError, ResponseError, TournamentError, PlayerError
+from pysmashgg.exceptions import TooManyRequestsError, ResponseError
 
 URL = "https://api.smash.gg/gql/alpha"
 
@@ -14,21 +14,11 @@ def run_query(query, variables, header):    # Returns the response or the error
             raise ResponseError
 
         response = request.json()
-        if 'errors' in response:
-            raise BadRequestError
-        if 'tournament' in response['data']:
-            if response['data']['tournament'] == None:
-                raise TournamentError
-
         return response
 
     except TooManyRequestsError:
         print("Sending too many requests right now, try again in like 30 seconds -- this will usually fix the error")
     except ResponseError:
         print("Unknown error, error code: " + str(request.status_code))
-    except BadRequestError:
-        print("Bad request, try again")
-    except TournamentError:
-        print("Tournament doesn't exist, try again")
 
     return
\ No newline at end of file
