@@ -1,5 +1,5 @@
 import requests
-from pysmashgg import exceptions, tournaments, brackets, players
+from pysmashgg import exceptions, tournaments, brackets, players, events
 
 class SmashGG(object):
     def __init__(self, key):
@@ -16,6 +16,10 @@ class SmashGG(object):
     def print_header(self):
         print(self.header)
 
+    # Event_id for a tournament
+    def tournament_show_event_id(self, tournament_name, event_name):
+        return tournaments.get_event_id(tournament_name, event_name, self.header)
+
     # Metadata for a tournament
     def tournament_show(self, tournament_name):
         return tournaments.show(tournament_name, self.header)
@@ -32,17 +36,17 @@ class SmashGG(object):
     def tournament_show_events(self, tournament_name):
         return tournaments.show_events(tournament_name, self.header)
 
-    # List of sets for an event -- Probably don't mess with sleep time
+    # List of sets for an event
     def tournament_show_sets(self, tournament_name, event_name, page_num):
         return tournaments.show_sets(tournament_name, event_name, page_num, self.header)
 
-    # List of entrants for an event -- Probably don't mess with sleep time
+    # List of entrants for an event
     def tournament_show_entrants(self, tournament_name, event_name, page_num):
         return tournaments.show_entrants(tournament_name, event_name, page_num, self.header)
     
     # Bracket info for an event at a tournament
-    def tournament_show_events_brackets(self, tournament_name, event_name):
-        return tournaments.show_events_brackets(tournament_name, event_name, self.header)
+    def tournament_show_event_brackets(self, tournament_name, event_name):
+        return tournaments.show_event_brackets(tournament_name, event_name, self.header)
     
     # Bracket info for all events at a tournament
     def tournament_show_all_event_brackets(self, tournament_name):
@@ -56,6 +60,14 @@ class SmashGG(object):
     def tournament_show_head_to_head(self, tournament_name, event_name, entrant1_name, entrant2_name):
         return tournaments.show_head_to_head(tournament_name, event_name, entrant1_name, entrant2_name, self.header)
 
+    # All tournaments with events (of a certain game) of a minimum size in between two unix timestamps
+    def tournament_show_event_by_game_size_dated(self, num_entrants, videogame_id, after, before, page_num):
+        return tournaments.show_event_by_game_size_dated(num_entrants, videogame_id, after, before, page_num, self.header)
+
+    # Results of an event with only entrant name, id, and placement
+    def tournament_show_lightweight_results(self, tournament_name, event_name, page_num):
+        return tournaments.show_lightweight_results(tournament_name, event_name, page_num, self.header)
+
     # All entrants in a bracket (phaseGroup) at a tournament
     def bracket_show_entrants(self, bracket_id, page_num):
         return brackets.bracket_show_entrants(bracket_id, page_num, self.header)
@@ -76,4 +88,24 @@ class SmashGG(object):
     # Use https://docs.google.com/spreadsheets/d/1l-mcho90yDq4TWD-Y9A22oqFXGo8-gBDJP0eTmRpTaQ/
     # to find the game_id you're looking for
     def player_show_tournaments_for_game(self, player_id, player_name, videogame_id, page_num):
-        return players.show_tournaments_for_game(player_id, player_name, videogame_id, page_num, self.header)
\ No newline at end of file
+        return players.show_tournaments_for_game(player_id, player_name, videogame_id, page_num, self.header)
+
+    # List of sets for an event
+    def event_show_sets(self, event_id, page_num):
+        return events.show_sets(event_id, page_num, self.header)
+
+    # List of entrants for an event
+    def event_show_entrants(self, event_id, page_num):
+        return events.show_entrants(event_id, page_num, self.header)
+
+    # All sets from an entrant at an event
+    def event_show_entrant_sets(self, event_id, entrant_name):
+        return events.show_entrant_sets(event_id, entrant_name, self.header)
+    
+    # All sets between two entrants at an event
+    def event_show_head_to_head(self, event_id, entrant1_name, entrant2_name):
+        return events.show_head_to_head(event_id, entrant1_name, entrant2_name, self.header)
+
+    # Results of an event with only entrant name, id, and placement
+    def event_show_lightweight_results(self, event_id, page_num):
+        return events.show_lightweight_results(event_id, page_num, self.header)
\ No newline at end of file
